@@ -1,18 +1,11 @@
-# -*- coding: Latin-1 -*-
+
 """peutils, Portable Executable utilities module
 
 
-Copyright (c) 2005-2022 Ero Carrera <ero.carrera@gmail.com>
+Copyright (c) 2005-2023 Ero Carrera <ero.carrera@gmail.com>
 
 All rights reserved.
 """
-from __future__ import division
-from future import standard_library
-
-standard_library.install_aliases()
-from builtins import range
-from builtins import object
-
 import os
 import re
 import string
@@ -586,7 +579,7 @@ def is_probably_packed(pe):
         if s_entropy > 7.4:
             total_compressed_data += s_length
 
-    if ((1.0 * total_compressed_data) / total_pe_data_length) > 0.2:
+    if (total_compressed_data / total_pe_data_length) > 0.2:
         has_significant_amount_of_compressed_data = True
 
     return has_significant_amount_of_compressed_data
